def nice_size(size, si=False, decimal_precision=1):
    """
    Returns a string representation of a file size in SI (KiB, MiB, etc.)
    or binary units (KB, MB, etc.)
    :param size: a size in single bytes
    :param si: whether to use SI units (or binary units, the default)
    :param decimal_precision: the number of decimals to show in rounded
        representations
    :return: a string representation of size
    """
    threshold = 1000 if si else 1024

    if abs(size) < threshold:
        return f'{size} B'

    units = ['kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'] if si \
        else ['KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB', 'ZiB', 'YiB']
    u = -1
    r = 10 ** decimal_precision

    while True:
        size /= threshold
        u += 1
        if round(abs(size) * r) / r < threshold or u == len(units) - 1:
            break

    # noinspection PyStringFormat
    return (f'%.{decimal_precision}f ' % size) + units[u]



from os import chdir
from treewalker import TreeWalker
from tempfile import TemporaryDirectory
from pathlib import Path
import unittest

chdir(Path(__file__).parent)


# TODO replace the simple class below with actual tests for your code in treewalker
class TestWalker(unittest.TestCase):
    def setUp(self) -> None:
        self.t = TemporaryDirectory()
        self.w = TreeWalker(Path(self.t.name) / 'test_walker.sqlite', rewrite=False)

    def tearDown(self) -> None:
        self.w.close()
        self.t.cleanup()

    def test_version_defined(self):
        try:
            from treewalker import __version__
        except ImportError:
            self.fail('__version__ not in package')

    def test_walk(self):
        self.w.walk('data\\dir')
        self.w.commit()
        self.assertEqual({'sub': {'test.txt': None}, 'test.txt': None}, self.w.get_tree('data\\dir'))

    def test_db_add(self):
        with TreeWalker(Path(self.t.name) / 'test_walker_two.sqlite', rewrite=False) as w:
            w.walk('data\\dir_two')

        self.w.walk('data\\dir')
        self.w.commit()
        self.w.add_db(str(Path(self.t.name) / 'test_walker_two.sqlite'))
        self.w.commit()
        self.assertEqual({
            'data\\dir': {'sub': {'test.txt': None}, 'test.txt': None},
            'data\\dir_two': {'sub2': {'test2.txt': None}, 'test2.txt': None}
        }, self.w.get_tree())

    def test_remove(self):
        self.w.walk('data\\dir')
        self.w.commit()
        self.w.remove('data\\dir\\sub')
        self.assertEqual({'test.txt': None}, self.w.get_tree('data\\dir'))
